/**
 * @package    Joomla.Installation
 *
 * @copyright  Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

body {
	direction: rtl;
}
/* Javascript Warning */
#javascript-warning {
	text-align: center;
	font-size: 16px;
}
textarea {
	resize: both;
}
textarea.vert {
	resize: vertical;
}
textarea.noResize {
	resize: none;
}
