@charset "UTF-8";

/**
 * @package		Joomla.Administrator
 * @subpackage	templates.hathor
 * @copyright	Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 * @since		1.6
 *
 * Changes to use high contrast colors
 */

/**
 * Main Colors
 * #163365	Text background/border
 * #1c4181  Alternative text background 1/border
 * #1b3f7c	Alternative text background 2/border
 * #fcff20	Text
 * #ffffff	Highlighted Text
 * #10254a	Main hover color/border
 * #000000	Highlight/shadow border
 * #a20000	Invalid Alert Color
 * #00f800	Success Alert Color
 * #feffbf  Disabled Menu/Protected
 *
 * MENU:
 *
 * Standard Link
 * #1b3f7c  Link Background
 * #ffffff	Text
 * #10254a	Border
 *
 * Pressed Link
 * #163365	Text background
 * #ffffff	Highlighted Text
 * #000000	Left & Top Border
 * #1b3f7c	Right & Bottom Border
 *
 * Background behind the links
 * #163365	Background
 * #122b56	Border
 *
 * Inactive (Disabled)
 * #cccccc	Text
 *
 * SUBMENU
 * #163365	Active Tab Background
 * #fcff20	Active Tab Text color
 * #10254a	Hover background
 * #10254a	Border
 * #1b3f7c	"off" Tab Background
 * #ffffff	"off" Tab Text color
 *
 * #1c4181	Color behind the tabs
 */

/**
 * General styles
 */
body {
	background-color: #1c4181;
	color: #fcff20;
}

div#sbox-content {
	background-color: #1c4181;
	color: #fcff20;
}

h1 {
	color: #163365;
}

a:link {
	color: #ffffff;
}

a:visited {
	color: #ffffff;
}

a:hover,a:focus {
	text-decoration: underline;
	color: #fcff20;
}

/**
 * Overall Styles
 */
#header {
	background: #ffffff url(../images/j_logo.png) no-repeat;
}

#header h1.title {
	color: #163365;
}

#footer {
	background: #163365;
	border: 1px solid #1b3f7c;
}

#nav {
	background: #163365;
	border: 1px solid #1b3f7c;
}

#content {
	background: #1c4181;
}

#no-submenu {
	border-bottom: 1px solid #1b3f7c;
}

#element-box {
	background: #163365;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #1b3f7c;
}

#element-box.login {
	border-top: 1px solid #1b3f7c;
}

/**
 * Status layout
 */
#module-status a, #module-status span {
	color: #163365;
}

#module-status .preview {
	background: url(../images/menu/icon-16-media.png) 3px 3px no-repeat;
}

#module-status .viewsite {
	background: url(../images/menu/icon-16-viewsite.png) 3px 3px no-repeat;
}

#module-status .unread-messages,#module-status .no-unread-messages {
	background: url(../images/menu/icon-16-messages.png) 3px 3px no-repeat;
}

#module-status .loggedin-users {
	background: url(../images/menu/icon-16-user.png) 3px 3px no-repeat;
}

#module-status .backloggedin-users {
	background: url(../images/menu/icon-16-back-user.png) 3px 3px no-repeat;
}

#module-status .multilanguage {
	background: url(../images/menu/icon-16-language.png) 3px 3px no-repeat;
}

#module-status .logout {
	background: url(../images/menu/icon-16-logout.png) 3px 3px no-repeat;
}

/**
 * Various Styles
 */
.enabled,
.success ,
.allow,
span.writable {
	color: #00f800;
}

.disabled,
p.error,
.warning,
.deny,
span.unwritable	{
	color: #a20000;
}

.nowarning {
	color: #fcff20;
}

.none,.protected {
	color: #feffbf;
}

span.note {
	background: #163365;
	color: #fcff20;
}

div.checkin-tick {
	background: url(../images/admin/tick.png) 20px 50% no-repeat;
}

/**
 * Overlib
 */
.ol-foreground {
	background-color: #fcff20;
}

.ol-background {
	background-color: #1b3f7c;
}

.ol-textfont {
	color: #163365;
}

.ol-captionfont {
	color: #ffffff;
}

.ol-captionfont a {
	color: #1b3f7c;
}

/**
 * Subheader, toolbar, page title
 */
.pagetitle h2 {
	color: #fcff20;
}

div.configuration {
	color: #fcff20;
	background-image: url(../images/menu/icon-16-config.png);
	background-repeat: no-repeat;
}

div.toolbar-box {
	border-right: 1px solid #10254a;
	border-bottom: 1px solid #10254a;
	border-left: 1px solid #10254a;
	background: #163365;
}

div.toolbar-list li {
	color: #fcff20;
}

div.toolbar-list li.divider {
	border-right:1px dotted #1b3f7c;
}

div.toolbar-list a {
	border: 1px solid #10254a;
	color: #fcff20;
	background: #1b3f7c;
}

div.toolbar-list a:hover {
	border-left: 1px solid #000000;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	background: #163365;
	color: #ffffff;
}

/**
 * Pane Slider pane Toggler styles
 */
.pane-sliders .title {
	color: #fcff20;
	border: 1px solid #10254a;
}

.pane-sliders .panel {
	border: 1px solid #1b3f7c;
}

.pane-sliders .panel h3 {
	background: #1c4181;
	color: #fcff20;
}

.pane-sliders .content {
	background: #163365;
}

.pane-sliders .adminlist {
	border: 0 none;
}

.pane-sliders .adminlist td {
	border: 0 none;
}

.pane-toggler  span {
	background: transparent url(../images/j_arrow.png) 5px 50% no-repeat;
}

.pane-toggler-down span {
	background: transparent url(../images/j_arrow_down.png) 5px 50%
		no-repeat;
}

.pane-toggler-down {
	border-bottom: 1px solid #1b3f7c;
}

/**
 * Tabs
 */
dl.tabs dt {
	border: 1px solid #10254a;
	background: #1c4181;
	color: #fcff20;
}

dl.tabs dt.open {
	background: #163365;
	border-bottom: 1px solid #163365;
	color: #fcff20;
}

dl.tabs dt.open a:visited {
	color: #fcff20;
}

div.current {
	border: 1px solid #10254a;
	background: #163365;
}

div.current dd {
	padding: 0;
	margin: 0;
}

div#menu-assignment h3 {
	border-bottom: 1px solid #fcff20;
}

/**
 * Login Settings
 */
#login-page .pagetitle h2 {
	background-color: transparent;
	/* background-color: #1c4181; */
	color: #fcff20;
}

#login-page #header {
	border-bottom: 1px solid #1b3f7c;
}

#login-page #content {
	background: #1c4181;
}

#login-page #lock {
	background: url(../images/j_login_lock.png) 50% 0 no-repeat;
}

#login-page #element-box.login {
	background: #163365;
	border: 1px solid #10254a;
}

#form-login {
	border: 1px solid #10254a;
	background: #1c4181;
}

#form-login label {
	color: #fcff20;
}

#form-login div.button1 a {
	color: #fcff20;
	background-color: #1b3f7c;
	border: 1px solid #10254a;
}

#form-login div.button1 a:hover,#form-login div.button1 a:focus {
	text-decoration: none;
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/**
 * Cpanel Settings
 */
.cpanel-page div#element-box {
	background: #163365;
	border: 1px solid #10254a;
}

#cpanel div.icon a, .cpanel div.icon a {
	border: 1px solid #10254a;
	background: #1b3f7c;
	color: #fcff20;
}

#cpanel div.icon a:hover,
#cpanel div.icon a:focus,
.cpanel div.icon a:hover,
.cpanel div.icon a:focus {
	border-left: 1px solid #000000;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	background: #163365;
	color: #ffffff;
}

/**
 * Form Styles
 */
fieldset {
	border: 3px dotted #1b3f7c;
}

legend {
	color: #fcff20;
}

fieldset ul.checklist input:focus {
	outline: thin dotted #333333;
}

fieldset#filter-bar {
	border-bottom: 1px solid #1b3f7c;
}

fieldset#filter-bar ol, fieldset#filter-bar ul {
	border: 0;
}

fieldset#filter-bar ol li fieldset, fieldset#filter-bar ul li fieldset {
	border: 0;
}

input,span.faux-input, select,option {
	color: #fcff20;
	background-color: #163365;
	border: 1px solid #1b3f7c;
}

/* Note: these visual cues should be augmented by aria */
.invalid {
	color: #a20000;
	background-color: #ffffff;
}

/* must be augmented by aria at the same time if changed dynamically by js
	aria-invalid=true or aria-invalid=false */
input.invalid {
	border: 1px solid #a20000;
}

input.required {
	background-color: #fcff20;
	color: #163365;
	border: 1px solid #1b3f7c;
}

input.disabled {
	background-color: #eeeeee;
}

/* Inputs used as buttons */
input[type="button"],
input[type="submit"],
input[type="reset"] {
	background-color: #1b3f7c;
	border: 1px solid #10254a;
	color: #fcff20;
}

input[type="button"]:hover, input[type="button"]:focus,
input[type="submit"]:hover, input[type="submit"]:focus,
input[type="reset"]:hover, input[type="reset"]:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

textarea {
	color: #fcff20;
	background-color: #163365;
	border: 1px solid #1b3f7c;
}

input:focus, select:focus, textarea:focus, option:focus,
input:hover, select:hover, textarea:hover, option:hover
	{
	background-color: #10254a;
	color: #fcff20;
}

/**
 * Option or Parameter styles
 */
.paramrules {
	background: #1b3f7c;
}

span.gi {
	color: #ffffff;
}


/**
 * Admintable Styles
 */
table.admintable td.key,table.admintable td.paramlist_key {
	background-color: #1c4181;
	color: #fcff20;
	border-bottom: 1px solid #10254a;
	border-right: 1px solid #10254a;
}

table.paramlist td.paramlist_description {
	background-color: #1c4181;
	color: #fcff20;
	border-bottom: 1px solid #10254a;
	border-right: 1px solid #10254a;
}

/**
 * Admin Form Styles
 */
fieldset.adminform {
	border: 1px solid #1b3f7c;
}

	/* Table styles are for use with tabular data */
table.adminform {
	background-color: #163365;
}

table.adminform tr.row0 {
	background-color: #163365;
}

table.adminform tr.row1 {
	background-color: #10254a;
}

table.adminform th {
	color: #fcff20;
	background: #163365;
}

table.adminform tr {
	border-bottom: 1px solid #1b3f7c;
	border-right: 1px solid #1b3f7c;
}

/**
 * Adminlist Table layout
 */
table.adminlist {
	background-color: #163365;
	color: #fcff20;
}

table.adminlist a {
	color: #ffffff;
}

table.adminlist thead th {
	background: #163365;
	color: #fcff20;
}

/* Table row styles */
table.adminlist tbody tr {
	background: #163365;
}

table.adminlist tbody tr.row1 {
	background: #163365;
}

table.adminlist tbody tr.row1 td,
table.adminlist tbody tr.row1 th {
	border-bottom: 1px solid #1b3f7c;
}

table.adminlist tbody tr.row0:hover td,
table.adminlist tbody tr.row1:hover td,
table.adminlist tbody tr.row0:hover th,
table.adminlist tbody tr.row1:hover th,
table.adminlist tbody tr.row0:focus td,
table.adminlist tbody tr.row1:focus td,
table.adminlist tbody tr.row0:focus th,
table.adminlist tbody tr.row1:focus th {
	background-color: #10254a;
}

table.adminlist tbody tr td,
table.adminlist tbody tr th {
	border-right: 1px solid #1b3f7c;
}

table.adminlist tbody tr td:last-child {
	border-right: none;
}

table.adminlist tbody tr.row0:last-child td,
table.adminlist tbody tr.row0:last-child th {
	border-bottom: 1px solid #1b3f7c;
}

table.adminlist tbody tr.row0 td,
table.adminlist tbody tr.row0 th {
	background: #1c4181;
}

table.adminlist tfoot tr {
	color: #fcff20;
}

/* Table td/th styles */
table.adminlist tfoot td,table.adminlist tfoot th {
	background-color: #163365;
	border-top: 1px solid #1b3f7c;
}

/**
 * Adminlist buttons
 */
table.adminlist tr td.btns a {
	background-color: #1b3f7c;
	border: 1px solid #10254a;
	color: #fcff20;
}

table.adminlist tr td.btns a:hover, table.adminlist tr td.btns a:active, table.adminlist tr td.btns a:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/**
 * Saving order icon styling in admin tables
 */
a.saveorder {
	background: url(../images/admin/filesave.png) no-repeat;
}

a.saveorder.inactive {
	background-position: 0 -16px;
}

/**
 * Saving order icon styling in admin tables
 */
fieldset.batch {
	background: #1c4181;
}


/**
 * Button styling
 */
button {
	color: #fcff20;
	background-color: #1b3f7c;
	border: 1px solid #10254a;
}

button:hover, button:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/* Button 1 Type */
.button1 {
	border: none;
	background: #1b3f7c;
}

	/* Use this if you add images to the buttons such as directional arrows */
.button1 .next {
	/* background: transparent url(../images/j_button1_next.png) 100% 0 no-repeat;  */
}

.button1 a {
	border: 1px solid #10254a;
	color: #fcff20;
}

.button1 a:hover,.button1 a:focus {
	text-decoration: none;
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/* Button 2 Type */
.button2-left,.button2-right {
	border: none;
	background: #1b3f7c;
}

.button2-left a,.button2-right a,.button2-left span,.button2-right span
	{
	color: #fcff20;
	border: 1px solid #10254a;
}

/* these are inactive buttons */
.button2-left span,.button2-right span {
	color: #cccccc;
	border: 1px solid #10254a;
}

.page span,.blank span {
	color: #fcff20;
	border: 1px solid #10254a;
}

.button2-left a:hover,.button2-right a:hover,.button2-left a:focus,.button2-right a:focus
	{
	text-decoration: none;
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/**
 * Pagination styles
 */

	/* Grey out the current page number */
.pagination .page span {
	color: #cccccc;
}

/**
 * Tooltips
 */
.tip {
	background: #000000;
	border: 1px solid #FFFFFF;
}

.tip-title {
	background: url(../images/selector-arrow-std.png) no-repeat;
}

/**
 * Calendar
 */
a img.calendar {
	background: url(../images/calendar.png) no-repeat;
}

/**
 * JGrid styles
 */
.jgrid span.publish {
	background-image: url(../images/admin/tick.png);
}

.jgrid span.unpublish {
	background-image: url(../images/admin/publish_x.png);
}

.jgrid span.archive {
	background-image: url(../images/menu/icon-16-archive.png);
}

.jgrid span.trash {
	background-image: url(../images/menu/icon-16-trash.png);
}

.jgrid span.default {
	background-image: url(../images/menu/icon-16-default.png);
}

.jgrid span.notdefault {
	background-image: url(../images/menu/icon-16-notdefault.png);
}

.jgrid span.checkedout {
	background-image: url(../images/admin/checked_out.png);
}

.jgrid span.downarrow {
	background-image: url(../images/admin/downarrow.png);
}

.jgrid span.downarrow_disabled {
	background-image: url(../images/admin/downarrow0.png);
}

.jgrid span.uparrow {
	background-image: url(../images/admin/uparrow.png);
}

.jgrid span.uparrow_disabled {
	background-image: url(../images/admin/uparrow0.png);
}

.jgrid span.published {
	background-image: url(../images/admin/publish_g.png);
}

.jgrid span.expired {
	background-image: url(../images/admin/publish_r.png);
}

.jgrid span.pending	{
	background-image: url(../images/admin/publish_y.png);
}

.jgrid span.warning	{
	background-image: url(../images/admin/publish_y.png);
}

/**
 * Menu Icons
 * These icons are used on the Administrator menu
 * The classes are constructed dynamically when the menu is generated
 */
.icon-16-archive {
	background-image: url(../images/menu/icon-16-archive.png);
}

.icon-16-article {
	background-image: url(../images/menu/icon-16-article.png);
}

.icon-16-banners {
	background-image: url(../images/menu/icon-16-banner.png);
}

.icon-16-banners-clients {
	background-image: url(../images/menu/icon-16-banner-client.png);
}

.icon-16-banners-tracks {
	background-image: url(../images/menu/icon-16-banner-tracks.png);
}

.icon-16-banners-cat {
	background-image: url(../images/menu/icon-16-banner-categories.png);
}

.icon-16-category {
	background-image: url(../images/menu/icon-16-category.png);
}

.icon-16-checkin {
	background-image: url(../images/menu/icon-16-checkin.png);
}

.icon-16-clear {
	background-image: url(../images/menu/icon-16-clear.png);
}

.icon-16-component {
	background-image: url(../images/menu/icon-16-component.png);
}

.icon-16-config {
	background-image: url(../images/menu/icon-16-config.png);
}

.icon-16-contact {
	background-image: url(../images/menu/icon-16-contacts.png);
}

.icon-16-contact-cat {
	background-image: url(../images/menu/icon-16-contacts-categories.png);
}

.icon-16-content {
	background-image: url(../images/menu/icon-16-content.png);
}

.icon-16-cpanel {
	background-image: url(../images/menu/icon-16-cpanel.png);
}

.icon-16-default {
	background-image: url(../images/menu/icon-16-default.png);
}

.icon-16-featured {
	background-image: url(../images/menu/icon-16-featured.png);
}

.icon-16-groups {
	background-image: url(../images/menu/icon-16-groups.png);
}

.icon-16-help {
	background-image: url(../images/menu/icon-16-help.png);
}

.icon-16-help-this {
	background-image: url(../images/menu/icon-16-help-this.png);
}

.icon-16-help-forum {
	background-image: url(../images/menu/icon-16-help-forum.png);
}

.icon-16-help-docs {
	background-image: url(../images/menu/icon-16-help-docs.png);
}

.icon-16-help-jed {
	background-image: url(../images/menu/icon-16-help-jed.png);
}

.icon-16-help-jrd {
	background-image: url(../images/menu/icon-16-help-jrd.png);
}

.icon-16-help-community {
	background-image: url(../images/menu/icon-16-help-community.png);
}

.icon-16-help-security {
	background-image: url(../images/menu/icon-16-help-security.png);
}

.icon-16-help-dev {
	background-image: url(../images/menu/icon-16-help-dev.png);
}

.icon-16-help-shop {
	background-image: url(../images/menu/icon-16-help-shop.png);
}

.icon-16-info {
	background-image: url(../images/menu/icon-16-info.png);
}

.icon-16-install {
	background-image: url(../images/menu/icon-16-install.png);
}

.icon-16-joomlaupdate {
	background-image: url(../images/menu/icon-16-install.png);
}

.icon-16-language {
	background-image: url(../images/menu/icon-16-language.png);
}

.icon-16-levels {
	background-image: url(../images/menu/icon-16-levels.png);
}

.icon-16-logout {
	background-image: url(../images/menu/icon-16-logout.png);
}

.icon-16-maintenance {
	background-image: url(../images/menu/icon-16-maintenance.png);
}

.icon-16-massmail {
	background-image: url(../images/menu/icon-16-massmail.png);
}

.icon-16-media {
	background-image: url(../images/menu/icon-16-media.png);
}

.icon-16-menu {
	background-image: url(../images/menu/icon-16-menu.png);
}

.icon-16-menumgr {
	background-image: url(../images/menu/icon-16-menumgr.png);
}

.icon-16-messages {
	background-image: url(../images/menu/icon-16-messaging.png);
}

.icon-16-messages-add {
	background-image: url(../images/menu/icon-16-new-privatemessage.png);
}

.icon-16-messages-read {
	background-image: url(../images/menu/icon-16-messages.png);
}

.icon-16-module {
	background-image: url(../images/menu/icon-16-module.png);
}

/* .icon-16-new 		{ background-image: url(../images/menu/icon-16-new.png); } */
.icon-16-newarticle {
	background-image: url(../images/menu/icon-16-newarticle.png);
}

.icon-16-newcategory {
	background-image: url(../images/menu/icon-16-newcategory.png);
}

.icon-16-newgroup {
	background-image: url(../images/menu/icon-16-newgroup.png);
}

.icon-16-newlevel {
	background-image: url(../images/menu/icon-16-newlevel.png);
}

.icon-16-newuser {
	background-image: url(../images/menu/icon-16-newuser.png);
}

.icon-16-plugin {
	background-image: url(../images/menu/icon-16-plugin.png);
}

.icon-16-profile {
	background-image: url(../images/menu/icon-16-user.png);
}

.icon-16-purge {
	background-image: url(../images/menu/icon-16-purge.png);
}

.icon-16-readmess {
	background-image: url(../images/menu/icon-16-readmess.png);
}

.icon-16-section {
	background-image: url(../images/menu/icon-16-section.png);
}

.icon-16-static {
	background-image: url(../images/menu/icon-16-static.png);
}

.icon-16-stats {
	background-image: url(../images/menu/icon-16-stats.png);
}

.icon-16-themes {
	background-image: url(../images/menu/icon-16-themes.png);
}

.icon-16-trash {
	background-image: url(../images/menu/icon-16-trash.png);
}

.icon-16-user {
	background-image: url(../images/menu/icon-16-user.png);
}

.icon-16-user-note {
	background-image: url(../images/menu/icon-16-user-note.png);
}

.icon-16-delete {
	background-image: url(../images/menu/icon-16-delete.png);
}

.icon-16-help-trans {
	background-image: url(../images/menu/icon-16-help-trans.png);
}

.icon-16-newsfeeds {
	background-image: url(../images/menu/icon-16-newsfeeds.png);
}

.icon-16-newsfeeds-cat {
	background-image: url(../images/menu/icon-16-newsfeeds-cat.png);
}

.icon-16-redirect {
	background-image: url(../images/menu/icon-16-redirect.png);
}

.icon-16-search {
	background-image: url(../images/menu/icon-16-search.png);
}

.icon-16-finder {
	background-image: url(../images/menu/icon-16-search.png);
}

.icon-16-weblinks {
	background-image: url(../images/menu/icon-16-links.png);
}

.icon-16-weblinks-cat {
	background-image: url(../images/menu/icon-16-links-cat.png);
}

/**
 * Toolbar icons
 * These icons are used for the toolbar buttons
 * The classes are constructed dynamically when the toolbar is created
 */
.icon-32-send {
	background-image: url(../images/toolbar/icon-32-send.png);
}

.icon-32-delete {
	background-image: url(../images/toolbar/icon-32-delete.png);
}

.icon-32-help {
	background-image: url(../images/toolbar/icon-32-help.png);
}

.icon-32-cancel {
	background-image: url(../images/toolbar/icon-32-cancel.png);
}

.icon-32-checkin {
	background-image: url(../images/toolbar/icon-32-checkin.png);
}

.icon-32-options{
	background-image: url(../images/toolbar/icon-32-config.png);
}

.icon-32-apply {
	background-image: url(../images/toolbar/icon-32-apply.png);
}

.icon-32-back {
	background-image: url(../images/toolbar/icon-32-back.png);
}

.icon-32-forward {
	background-image: url(../images/toolbar/icon-32-forward.png);
}

.icon-32-save {
	background-image: url(../images/toolbar/icon-32-save.png);
}

.icon-32-edit {
	background-image: url(../images/toolbar/icon-32-edit.png);
}

.icon-32-copy {
	background-image: url(../images/toolbar/icon-32-copy.png);
}

.icon-32-move {
	background-image: url(../images/toolbar/icon-32-move.png);
}

.icon-32-new {
	background-image: url(../images/toolbar/icon-32-new.png);
}

.icon-32-upload {
	background-image: url(../images/toolbar/icon-32-upload.png);
}

.icon-32-assign {
	background-image: url(../images/toolbar/icon-32-publish.png);
}

.icon-32-html {
	background-image: url(../images/toolbar/icon-32-html.png);
}

.icon-32-css {
	background-image: url(../images/toolbar/icon-32-css.png);
}

.icon-32-menus {
	background-image: url(../images/toolbar/icon-32-menu.png);
}

.icon-32-publish {
	background-image: url(../images/toolbar/icon-32-publish.png);
}

.icon-32-unblock {
	background-image: url(../images/toolbar/icon-32-unblock.png);
}

.icon-32-unpublish {
	background-image: url(../images/toolbar/icon-32-unpublish.png);
}

.icon-32-restore {
	background-image: url(../images/toolbar/icon-32-revert.png);
}

.icon-32-trash {
	background-image: url(../images/toolbar/icon-32-trash.png);
}

.icon-32-archive {
	background-image: url(../images/toolbar/icon-32-archive.png);
}

.icon-32-unarchive {
	background-image: url(../images/toolbar/icon-32-unarchive.png);
}

.icon-32-preview {
	background-image: url(../images/toolbar/icon-32-preview.png);
}

.icon-32-default {
	background-image: url(../images/toolbar/icon-32-default.png);
}

.icon-32-refresh {
	background-image: url(../images/toolbar/icon-32-refresh.png);
}

.icon-32-save-new {
	background-image: url(../images/toolbar/icon-32-save-new.png);
}

.icon-32-save-copy {
	background-image: url(../images/toolbar/icon-32-save-copy.png);
}

.icon-32-error {
	background-image: url(../images/toolbar/icon-32-error.png);
}

.icon-32-new-style {
	background-image: url(../images/toolbar/icon-32-new-style.png);
}

.icon-32-delete-style {
	background-image: url(../images/toolbar/icon-32-delete-style.png);
}

.icon-32-purge {
	background-image: url(../images/toolbar/icon-32-purge.png);
}

.icon-32-remove {
	background-image: url(../images/toolbar/icon-32-remove.png);
}

.icon-32-featured {
	background-image: url(../images/toolbar/icon-32-featured.png);
}

.icon-32-unfeatured {
	background-image: url(../images/toolbar/icon-32-featured.png);
	background-position: 0% 100%;
}

.icon-32-export {
	background-image: url(../images/toolbar/icon-32-export.png);
}

.icon-32-stats {
	background-image: url(../images/toolbar/icon-32-stats.png);
}

.icon-32-print {
	background-image: url(../images/toolbar/icon-32-print.png);
}

.icon-32-batch {
	background-image: url(../images/toolbar/icon-32-batch.png);
}

.icon-32-envelope {
	background-image: url(../images/toolbar/icon-32-messaging.png);
}
.icon-32-download {
	background-image: url(../images/toolbar/icon-32-export.png);
}

.icon-32-bars {
	background-image: url(../images/toolbar/icon-32-stats.png);
}

/**
 * Quick Icons
 * Also knows as Header Icons
 * These are used for the Quick Icons on the Control Panel
 * The same classes are also assigned the Component Title
 */
.icon-48-categories {
	background-image: url(../images/header/icon-48-category.png);
}

.icon-48-category-edit {
	background-image: url(../images/header/icon-48-category.png);
}

.icon-48-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-generic {
	background-image: url(../images/header/icon-48-generic.png);
}

.icon-48-banners {
	background-image: url(../images/header/icon-48-banner.png);
}

.icon-48-banners-categories {
	background-image: url(../images/header/icon-48-banner-categories.png);
}

.icon-48-banners-category-edit {
	background-image: url(../images/header/icon-48-banner-categories.png);
}

.icon-48-banners-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-banners-clients {
	background-image: url(../images/header/icon-48-banner-client.png);
}

.icon-48-banners-tracks {
	background-image: url(../images/header/icon-48-banner-tracks.png);
}

.icon-48-checkin {
	background-image: url(../images/header/icon-48-checkin.png);
}

.icon-48-clear {
	background-image: url(../images/header/icon-48-clear.png);
}

.icon-48-contact {
	background-image: url(../images/header/icon-48-contacts.png);
}

.icon-48-contact-categories {
	background-image: url(../images/header/icon-48-contacts-categories.png);
}

.icon-48-contact-category-edit {
	background-image: url(../images/header/icon-48-contacts-categories.png);
}

.icon-48-contact-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-purge {
	background-image: url(../images/header/icon-48-purge.png);
}

.icon-48-cpanel {
	background-image: url(../images/header/icon-48-cpanel.png);
}

.icon-48-config {
	background-image: url(../images/header/icon-48-config.png);
}

.icon-48-groups {
	background-image: url(../images/header/icon-48-groups.png);
}

.icon-48-groups-add {
	background-image: url(../images/header/icon-48-groups-add.png);
}

.icon-48-levels {
	background-image: url(../images/header/icon-48-levels.png);
}

.icon-48-levels-add {
	background-image: url(../images/header/icon-48-levels-add.png);
}

.icon-48-module {
	background-image: url(../images/header/icon-48-module.png);
}

.icon-48-menu {
	background-image: url(../images/header/icon-48-menu.png);
}

.icon-48-menu-add {
	background-image: url(../images/header/icon-48-menu-add.png);
}

.icon-48-menumgr {
	background-image: url(../images/header/icon-48-menumgr.png);
}

.icon-48-trash {
	background-image: url(../images/header/icon-48-trash.png);
}

.icon-48-user {
	background-image: url(../images/header/icon-48-user.png);
}

.icon-48-user-add {
	background-image: url(../images/header/icon-48-user-add.png);
}

.icon-48-user-edit {
	background-image: url(../images/header/icon-48-user-edit.png);
}

.icon-48-user-profile {
	background-image: url(../images/header/icon-48-user-profile.png);
}

.icon-48-inbox {
	background-image: url(../images/header/icon-48-inbox.png);
}

.icon-48-new-privatemessage {
	background-image: url(../images/header/icon-48-new-privatemessage.png);
}

.icon-48-msgconfig {
	background-image: url(../images/header/icon-48-message_config.png);
}

.icon-48-langmanager {
	background-image: url(../images/header/icon-48-language.png);
}

.icon-48-mediamanager {
	background-image: url(../images/header/icon-48-media.png);
}

.icon-48-plugin {
	background-image: url(../images/header/icon-48-plugin.png);
}

.icon-48-help_header {
	background-image: url(../images/header/icon-48-help_header.png);
}

.icon-48-impressions {
	background-image: url(../images/header/icon-48-stats.png);
}

.icon-48-browser {
	background-image: url(../images/header/icon-48-stats.png);
}

.icon-48-searchtext {
	background-image: url(../images/header/icon-48-stats.png);
}

.icon-48-thememanager {
	background-image: url(../images/header/icon-48-themes.png);
}

.icon-48-assoc {
	background-image: url(../images/header/icon-48-assoc.png);
}

.icon-48-writemess {
	background-image: url(../images/header/icon-48-writemess.png);
}

.icon-48-featured {
	background-image: url(../images/header/icon-48-featured.png);
}

.icon-48-sections {
	background-image: url(../images/header/icon-48-section.png);
}

.icon-48-article-add {
	background-image: url(../images/header/icon-48-article-add.png);
}

.icon-48-article-edit {
	background-image: url(../images/header/icon-48-article-edit.png);
}

.icon-48-article {
	background-image: url(../images/header/icon-48-article.png);
}

.icon-48-content-categories {
	background-image: url(../images/header/icon-48-category.png);
}

.icon-48-content-category-edit {
	background-image: url(../images/header/icon-48-category.png);
}

.icon-48-content-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-install {
	background-image: url(../images/header/icon-48-extension.png);
}

.icon-48-dbbackup {
	background-image: url(../images/header/icon-48-backup.png);
}

.icon-48-dbrestore {
	background-image: url(../images/header/icon-48-dbrestore.png);
}

.icon-48-dbquery {
	background-image: url(../images/header/icon-48-query.png);
}

.icon-48-systeminfo {
	background-image: url(../images/header/icon-48-info.png);
}

.icon-48-massmail {
	background-image: url(../images/header/icon-48-massmail.png);
}

.icon-48-redirect {
	background-image: url(../images/header/icon-48-redirect.png);
}

.icon-48-search	{
	background-image: url(../images/header/icon-48-search.png);
}

.icon-48-finder	{
	background-image: url(../images/header/icon-48-search.png);
}

.icon-48-newsfeeds {
	background-image: url(../images/header/icon-48-newsfeeds.png);
}

.icon-48-newsfeeds-categories {
	background-image: url(../images/header/icon-48-newsfeeds-cat.png);
}

.icon-48-newsfeeds-category-edit {
	background-image: url(../images/header/icon-48-newsfeeds-cat.png);
}

.icon-48-newsfeeds-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-weblinks {
	background-image: url(../images/header/icon-48-links.png);
}

.icon-48-weblinks-categories {
	background-image: url(../images/header/icon-48-links-cat.png);
}

.icon-48-weblinks-category-edit {
	background-image: url(../images/header/icon-48-links-cat.png);
}

.icon-48-weblinks-category-add {
	background-image: url(../images/header/icon-48-category-add.png);
}

.icon-48-tags {
	background-image: url(../images/header/icon-48-tags.png);
}

/**
 * General styles
 */
div.message {
	border: 1px solid #1b3f7c;
	color: #333;
}

.helpFrame {
	border-left: 0 solid #1b3f7c;
	border-right: none;
	border-top: none;
	border-bottom: none;
}

/**
 * Override mootree.css styles
 * media/system/css/mootree.css
 */
.mooTree_selected	 {
	background-color: #10254a;
}

/**
 * Modal Styles
 */
dl.menu_type dt {
	border-bottom: 1px solid #1b3f7c;
}

ul#new-modules-list {
	border-top: 1px solid #1b3f7c;
}

/**
 * Override mediamanager.css styles
 * administrator/components/com_media/assets/mediamanager.css
 */
#folderview input#folderpath {
	width: 65%;
	color: #fcff20;
	background-color: #163365;
	border: 1px solid #1b3f7c;
}

.upload-queue .queue-loader {
	background-color: #fcff20;
	color: #163365;
	border: 1px inset #fcff20;
}

.upload-queue .queue-subloader {
	background-color: #1b3f7c;
	color: #fcff20;
}

/**
 * User Accessibility
 */

	/* Skip to Content Visual Styling */
#skiplinkholder a, #skiplinkholder a:link, #skiplinkholder a:visited {
	color: #163365;
	background: #fcff20;
}

/**
 * Admin Form Styles
 */
fieldset.panelform {
	border: none 0;
}

/**
 * ACL STYLES relocated from com_users/media/grid.css
 */
a.move_up {
	background-image: url('../images/admin/uparrow.png');
}

span.move_up {
	background-image: url('../images/admin/uparrow0.png');
}

a.move_down {
	background-image: url('../images/admin/downarrow.png');
}

span.move_down {
	background-image: url('../images/admin/downarrow0.png');
}

a.grid_false {
	background-image: url('../images/admin/publish_x.png');
}

a.grid_true {
	background-image: url('../images/admin/tick.png');
}

a.grid_trash {
	background-image: url('../images/admin/icon-16-trash.png');
}

/**
 * ACL PANEL STYLES
 */

/* All Tabs */

tr.row1 {
	background-color: #1c4181;
}

/* Summary Tab */
table.aclsummary-table td.col2,
table.aclsummary-table th.col2,
table.aclsummary-table td.col3,
table.aclsummary-table th.col3,
table.aclsummary-table td.col4,
table.aclsummary-table th.col4,
table.aclsummary-table td.col5,
table.aclsummary-table th.col5,
table.aclsummary-table td.col6,
table.aclsummary-table th.col6,
table.aclmodify-table td.col2,
table.aclmodify-table th.col2 {
	border-left: 1px solid #cbcbcb;
}

/* Icons */

span.icon-16-unset {
	background: url(../images/admin/icon-16-denyinactive.png) no-repeat;
}

span.icon-16-allowed {
	background: url(../images/admin/icon-16-allow.png) no-repeat;
}

span.icon-16-denied {
	background: url(../images/admin/icon-16-deny.png) no-repeat;
}

span.icon-16-locked {
	background: url(../images/admin/checked_out.png) 0 0 no-repeat;
}

label.icon-16-allow {
	background: url(../images/admin/icon-16-allow.png) no-repeat;
}

label.icon-16-deny {
	background: url(../images/admin/icon-16-deny.png) no-repeat;
}
a.icon-16-allow {
	background: url(../images/admin/icon-16-allow.png) no-repeat ;
}
a.icon-16-deny {
	background: url(../images/admin/icon-16-deny.png) no-repeat ;
}
a.icon-16-allowinactive {
	background: url(../images/admin/icon-16-allowinactive.png) no-repeat ;
}
a.icon-16-denyinactive {
	background: url(../images/admin/icon-16-denyinactive.png) no-repeat ;
}

/* ACL footer/legend */

ul.acllegend li.acl-allowed {
	background: url(../images/admin/icon-16-allow.png) no-repeat left;
}

ul.acllegend li.acl-denied {
	background: url(../images/admin/icon-16-deny.png) no-repeat left;
}

li.acl-editgroups,
li.acl-resetbtn {
	background-color: #1b3f7c;
	border: 1px solid #10254a;
}

li.acl-editgroups a,
li.acl-resetbtn a {
	color: #fcff20
}

li.acl-editgroups:hover,
li.acl-resetbtn:hover,
li.acl-editgroups:focus,
li.acl-resetbtn:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/* ACL Config --------- */
table#acl-config {
	border: 1px solid #10254a;
	background: #1c4181;
}

table#acl-config th,
table#acl-config td {
	background: #1c4181;
	border-bottom: 1px solid #10254a;
	border-top: none;
	border-left: none;
	border-right: none;
}

table#acl-config th.acl-groups {
	border-right: 1px solid #10254a;
}

/**
* Mod_rewrite Warning
*/
#jform_sef_rewrite-lbl {
	background: url(../images/admin/icon-16-notice-note.png) right top no-repeat;
}

/**
* Options modal- config
*/

/* *
* Permission Rules
*/

#permissions-sliders ul#rules,
#permissions-sliders ul#rules ul {
    border:solid 0 #1b3f7c;
    background:#163365;
}

ul#rules li .pane-sliders .panel h3.title {
	border:solid 0 #1b3f7c;
}

#permissions-sliders ul#rules .pane-slider {
	border:solid 1px #1b3f7c;
}

#permissions-sliders ul#rules li h3 {
	background:#1c4181;
	border: 1px solid #1b3f7c;
}

#permissions-sliders ul#rules li h3.pane-toggler-down a {
	border:solid 0;
}

#permissions-sliders ul#rules .group-kind {
	color:#fcff20;
}

#permissions-sliders ul#rules table.group-rules td {
    border-right:solid 1px #1b3f7c;
    border-bottom:solid 1px #1b3f7c;
}

#permissions-sliders ul#rules table.group-rules th {
    background: #10254a;
    border-right:solid 1px #1b3f7c;
    border-bottom:solid 1px #1b3f7c;
    color:#fcff20;
}

ul#rules table.aclmodify-table {
	border:solid 1px #fcff20;
}

ul#rules table.group-rules td label {
	border:solid 0 #1b3f7c;
}

#permissions-sliders ul#rules .mypanel {
	border:solid 0 #1b3f7c;
}

#permissions-sliders  ul#rules  table.group-rules td {
   background: #163365;
}

#permissions-sliders span.level {
	color:#ffffff;
	background-image:none;
}

/*
 * Debug styles
 */
.check-0,
table.adminlist tbody td.check-0,
table.adminlist tbody tr:hover td.check-0 {
	background-color: #FFFFCF;
	color: #163365;
}

.check-a,
table.adminlist tbody td.check-a,
table.adminlist tbody tr:hover td.check-a {
	background-color: #CFFFDA;
	color: #163365;
}

.check-d,
table.adminlist tbody td.check-d,
table.adminlist tbody tr:hover td.check-d {
	background-color: #FFCFCF;
	color: #163365;
}

/**
 * System Messages
 */

#system-message dd ul {
	color: #fcff20;
	border-top: 3px solid #84A7DB;
	border-bottom: 3px solid #84A7DB;
}

#system-message dd.error ul {
	color: #fcff20;
	background: #1c4181 url(../images/notice-alert.png) 4px top no-repeat;
	border-top: 3px solid #a20000;
	border-bottom: 3px solid #a20000;
}

#system-message dd.message ul {
	color: #fcff20;
	background: #10254a url(../images/notice-info.png) 4px center no-repeat;
	border-top: 3px solid #EFE7B8;
	border-bottom: 3px solid #EFE7B8;
}

#system-message dd.notice ul {
	color: #fcff20;
	background: #10254a url(../images/notice-note.png) 4px top no-repeat;
	border-top: 3px solid #F0DC7E;
	border-bottom: 3px solid #F0DC7E;
}

/** CSS file for Accessible Admin Menu
 * based on Matt Carrolls' son of suckerfish
 * with javascript by Bill Tomczak
 */

	/* Note: set up the font-size on the id and used 100% on the elements.
	If ul/li/a are different ems, then the shifting back via non-js keyboard
	doesn't work properly */

/**
 * Menu Styling
 */
#menu { /* this is on the main ul */
	color: #ffffff;
}

#menu ul { /* all lists */
	background-color: #163365;
	color: #ffffff;
}

#menu ul li.node {
	background: #163365 url(../images/j_arrow.png) no-repeat right 50%;
}

#menu a {
	color: #ffffff;
	background-repeat: no-repeat;
	background-position: left 50%;
	background-color: #1b3f7c;
}

#menu li { /* all list items */
	background-color: #163365;
	border-right: 1px solid #000000;
}

#menu li a {
	border: 1px solid #10254a;
}

#menu li li a {
	border: 1px solid #10254a;
}

#menu li a:hover,
#menu li a:active,
#menu li a:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #ffffff;
}

#menu li.disabled a:hover,
#menu li.disabled a:focus,
#menu li.disabled a {
	color: #feffbf;
	background-color: #1b3f7c;
	border-top: 1px solid #163365;
	border-right: 1px solid #10254a;
	border-bottom: 1px solid #163365;
	border-left: 1px solid #10254a;
}

#menu li ul { /* second-level lists */
	border-top: 1px solid #10254a;
	border-bottom: 2px solid #10254a;
}

#menu li li { /* second-level row */
	background-color: #163365;
}

#menu li:hover ul,#menu li.sfhover ul {
	/* lists nested under hovered list items */
	margin-left: 0;
	border-left: 1px solid #122b56;
	border-right: 1px solid #122b56;
}

#menu li li:hover ul,#menu li li.sfhover ul {
	border-left: 1px solid #122b56;
	border-right: 1px solid #122b56;
}

/**
 * Styling parents
 */

 	/* 1 level - sfhover */
#menu li.sfhover a {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

	/* 2 level - normal */
#menu li.sfhover li a { /* background-color: #f0f0f0; */
	background-color: #1b3f7c;
	border: 1px solid #10254a;
	color: #ffffff;
}

	/* 2 level - hover */
#menu li.sfhover li.sfhover a,#menu li li a:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

	/* 3 level - normal */
#menu li.sfhover li.sfhover li a {
	background-color: #1b3f7c;
	border: 1px solid #10254a;
	color: #ffffff;
}

	/* 3 level - hover */
#menu li.sfhover li.sfhover li.sfhover a {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #fcff20;
}

/* bring back the focus elements into view */
#menu li li a:focus, #menu li li li a:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #ffffff;
}

#menu li li li a:focus {
	background-color: #163365;
	border-top: 1px solid #000000;
	border-right: 1px solid #1b3f7c;
	border-bottom: 1px solid #1b3f7c;
	border-left: 1px solid #000000;
	color: #ffffff;
}

/**
 * Submenu styling
 */
#submenu {
	border-bottom: 1px solid #10254a;
	/* border-bottom plus padding-bottom is the technique */
	/* This is the background befind the tabs */
	background: #1c4181;
}

#submenu a, #submenu span.nolink {
	background: #1b3f7c;
	border: 1px solid #10254a;
	color: #ffffff;
}

#submenu a:hover, #submenu a:focus {
	background-color: #10254a;
}

#submenu a.active, #submenu span.nolink.active {
	background: #163365;
	border-bottom: 1px solid #163365;
	color: #fcff20;
}

/**
 * Webkit fixes
 **/
input:-webkit-autofill {
	background-color: #163365 !important;
}

/* -- Codemirror Editor  ----------- */
div.editor-border, div.CodeMirror-wrapping {
	border: 1px solid #163365;
	background-color: #ffffff;
}

/* User Notes */
div.unotes h1 {
	background-color: #ffffff;
}
ul.alternating > li:nth-child(odd) { background-color: #163365; }
ul.alternating > li:nth-child(even) { background-color: #10254a; }
ol.alternating > li:nth-child(odd) { background-color: #163365; }
ol.alternating > li:nth-child(even) { background-color: #10254a;}

/* Installer Database */
#installer-database, #installer-discover, #installer-update, #installer-warnings {
	border-top: 1px solid #1b3f7c;
}
#installer-database p.warning {
	background: transparent url(../images/admin/icon-16-deny.png) center left no-repeat;
}

#installer-database p.nowarning {
	background: transparent url(../images/admin/icon-16-allow.png) center left no-repeat;
}
