/**
 * @package    Joomla.Installation
 *
 * @copyright  Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
.container{
	position: relative;
	max-width: 900px;
	z-index: 1060;
}
.thumbnail {
	margin-bottom:9px;
}
.accordion-group {
	background:#fff;
}

.step.active span {
	background-color: #f89406;
}

.header {
	background-color: #ffffff;
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#d9effa), color-stop(25%, #d9effa), to(#ffffff));
	background-image: -webkit-linear-gradient(#d9effa, #d9effa 25%, #ffffff);
	background-image: -moz-linear-gradient(top, #d9effa, #d9effa 25%, #ffffff);
	background-image: -ms-linear-gradient(#d9effa, #d9effa 25%, #ffffff);
	background-image: -o-linear-gradient(#d9effa, #d9effa 25%, #ffffff);
	background-image: linear-gradient(#d9effa, #d9effa 25%, #ffffff);
	background-repeat: no-repeat;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#d9effa', endColorstr='#ffffff', GradientType=0);
	border-top: 3px solid #0088cc;
	padding: 20px 0;
	text-align: center;
}

.hero-unit{
	background-color: #08C;
}
.hero-unit h1,
.hero-unit p,
.hero-unit > *{
	color: white;
	text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.5);
}
/* Page Edit */
.page-edit {
	background:#555 url(../img/noise.png);
	-moz-box-shadow: 0px 0px 40px #111 inset;
	-webkit-box-shadow: 0px 0px 40px #111 inset;
	box-shadow: 0px 0px 40px #111 inset;
}
.page-edit-inner {
	padding:20px 0;
}
.page-edit h1,
.page-edit h2,
.page-edit h3,
.page-edit h4,
.page-edit h5,
.page-edit h6,
.page-edit legend,
.page-edit label,
.page-edit p{
	color: #F8F8F8;
	text-shadow: 1px 1px 1px #000;
}
.page-edit legend,
.page-edit hr{
	border: 0;
	border-bottom: 1px solid #333;
}
.page-edit .form-actions{
	background-color: transparent;
	border-top: 1px solid #333;
}
/* Module */
.module-header {
	padding-bottom: 17px;
	margin: 20px 0 18px 0;
	border-bottom: 1px solid #eeeeee;
}
/* Single Item */
.item-title {
	margin-bottom:9px;
}
.item-content {
	margin:18px 0;
}
.item-subtitle {
	margin-bottom:9px;
}
.pull-right.item-image {
	margin:0 0 18px 20px;
}
.pull-left.item-image {
	margin:0 20px 18px 0;
}
.header .nav > li:last-child > .dropdown-menu,
.item-actions .dropdown-menu,
.item-comment .dropdown-menu {
	left:initial;
	right:0;
}
/* List */
.list-item-title {
	margin-bottom:9px;
}
.list-item-content {
	margin:18px 0;
}
.list-item-subtitle {
	margin-bottom:9px;
}
/* Javascript Warning */
#javascript-warning {
	text-align: center;
	font-size: 16px;
}
textarea {
	resize: both;
}
textarea.vert {
	resize: vertical;
}
textarea.noResize {
	resize: none;
}
/* Tooltip */
.tooltip {
	white-space: pre-wrap;
}

/* Flat Repaint */
.btn {
	background-image: none;
	border: 1px solid rgba(0, 0, 0, 0.2);
	box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}
.btn-primary:hover, .btn-primary:focus {
    background-color: #185b91;
    color: #fff;
    text-decoration: none;
}
.chzn-container-single .chzn-single {
    background-color: #ffffff;
    background-image: none;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 3px;
    box-shadow: 0 1px 0 rgba(255, 255, 255, 0.2) inset, 0 1px 2px rgba(0, 0, 0, 0.05);
    height: auto;
    line-height: 26px;
}
.chzn-container-single .chzn-single div {
    background-color: #f3f3f3;
    border-left: 1px solid #cccccc;
    text-align: center;
    width: 28px;
    height: auto;
    bottom: 0;
}
.chzn-container-single .chzn-drop {
    background-clip: padding-box;
    border-color: #0088cc;
}
.chzn-container-active .chzn-single {
    color: #0088cc;
}
.chzn-container-active.chzn-with-drop .chzn-single div {
    border-bottom: 1px solid #cccccc;
    border-bottom-left-radius: 3px;
    background-color: #f3f3f3;
    border-left: 1px solid #cccccc;
}
.chzn-container-single .chzn-single div b {
	background-position: 2px 2px;
    display: inline-block;
    height: 16px;
    width: 16px;
}
.chzn-container-active.chzn-with-drop  .chzn-single div b {
	background-position: -16px 2px;
}
.chzn-container-active.chzn-with-drop .chzn-single {
	background-image: none;
    border: 1px solid #0088cc;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.chzn-container .chzn-results {
    background-color: #fff;
    border-radius: 0 0 3px 3px;
    margin: 0;
    padding: 0;
}
.chzn-container-single .chzn-search input[type="text"] {
    border: 1px solid #aaa;
    border-radius: 3px;
    box-shadow: none;
    background: transparent url("../../../media/jui/css/chosen-sprite.png") no-repeat scroll 100% -20px
}
.chzn-container .chzn-results li.highlighted {
  background-color: #0088cc;
  background-image: none;
}
.chzn-container-single .chzn-search input[type="text"]:focus {
	border-color: #0088cc;
}
fieldset {
	margin-bottom: 10px;
}
textarea, input[type="text"], input[type="password"], input[type="datetime"], input[type="datetime-local"], input[type="date"], input[type="month"], input[type="time"], input[type="week"], input[type="number"], input[type="email"], input[type="url"], input[type="search"], input[type="tel"], input[type="color"], .uneditable-input {
	box-shadow: 0 1px 0 rgba(255, 255, 255, 0.2) inset, 0 1px 2px rgba(0, 0, 0, 0.05);
}

#jform_activateMultilanguage [class*="btn-"]:active,
#jform_activateMultilanguage [class*="btn-"].active,
#jform_installLocalisedContent [class*="btn-"]:active,
#jform_installLocalisedContent [class*="btn-"].active,
#jform_activatePluginLanguageCode [class*="btn-"]:active,
#jform_activatePluginLanguageCode [class*="btn-"].active {
    background-color: #294f7e;
}
