<?php
/**
 * @package     Joomla.Installation
 * @subpackage  Controller
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * Controller class to remove the old database for the Joomla Installer.
 *
 * @since  3.1
 */
class InstallationControllerInstallDatabase_remove extends InstallationControllerInstallDatabase_backup
{
}
