/**
 * @copyright	Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

.contentpane {
	padding: 0 !important;
	overflow-x: hidden;
}

.item {
	float: left;
	border: 1px solid #ccc !important;
	margin: 3px;
	position: relative;
	padding: 0 !important;
}

.item a {
	display: table-cell !important;
	display: block;
	width: 80px;
	height: 90px;
	overflow: hidden;
	vertical-align: middle;
	text-align: center;
	text-decoration: none;
	color: black;
	line-height: 90px;
	background: #fff !important;
}

.item img {
	display: inline;
	margin-top: expression(( 80 - this.height ) / 2);
	border: 0;
}

html>body .item img {
	margin: auto;
}

.item span {
	line-height: 100%;
	clear: both;
	display: block;
	width: 100%;
	position: absolute;
	bottom: 0;
	left: 0;
	padding: 2px 0;
	background-color: #eee;
	overflow: hidden;
	font-family: Tahoma, Verdana, sans-serif !important;
	font-size: 11px;
}

.item  a:link span,
.item a:visited span {
	background-color: #eee;
	color: #333;
}

.item  a:hover span,
.item a:active span,
.item a:active focus {
	background-color: #eee;
	color: #095197;
}

.thumbnails.thumbnails-media {
	margin: 0 -8px;
}
.thumbnails-media .thumbnail {
	background-color: #f4f4f4;
	border-radius: 3px;
	border: 0;
	box-shadow: 0 0 0 1px rgba(0,0,0,0.05) inset;
	padding: 0px;
	height: 100px;
	width: 100px;
	margin: 8px;
	position: relative;
	text-align: center;
	overflow: hidden;
}
.thumbnails-media .thumbnail .close {
	background-color: #ccc;
	border-left: 1px solid rgba(0,0,0,0.1);
	height: 22px;
	line-height: 22px;
	opacity: 0.3;
	text-align: center;
	width: 22px;
	top: 0;
	right: 0;
}
.thumbnails-media .thumbnail .close:hover {
	background-color: #bbb;
}
.thumbnails-media .thumbnail *,
.thumbnails-media .thumbnail *:before {
	-webkit-transition: all 0.2s ease;
	transition: all 0.2s ease;
	-webkit-background-clip: padding-box;
	background-clip: padding-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
}
.thumbnails-media .thumbnail input[type="radio"],
.thumbnails-media .thumbnail input[type="checkbox"] {
	margin: 0;
	opacity: 0.55;
	position: absolute;
	top: 5px;
	left: 5px;
}
.thumbnails-media .thumbnail .controls,
.thumbnails-media .thumbnail .imginfoBorder {
	display: none;
}
.thumbnails-media .imgThumb {
	position: relative;
	z-index: 1;
	width: 100%;
	display: inline-block;
}
.thumbnails-media .imgThumb input {
	display: none;
}
.thumbnails-media .imgThumb label,
.thumbnails-media .imgThumb .imgThumbInside {
	display: block;
	line-height: 100px;
	position: relative;
	width: 100%;
	border-radius: 3px;
	overflow: hidden;
}
.thumbnails-media .imgThumb label:before,
.thumbnails-media .imgThumb .imgThumbInside:before {
	font-family: "IcoMoon";
	font-style: normal;
	content: 'G';
	position: absolute;
	top: 0;
	right: 0;
	background-color: #46a546;
	color: #fff;
	line-height: 26px;
	width: 26px;
	-webkit-transform: scale(0.5);
	transform: scale(0.5);
	opacity: 0;
	border-color: rgba(0,0,0,0.2);
	box-shadow: 0 1px 2px rgba(0,0,0,0.05);
	border-radius: 0 3px;
}
.thumbnails-media .imgThumb img {
	width: auto;
}
.thumbnails-media .selected :checked + label,
.thumbnails-media .selected .imgThumbInside,
.thumbnails-media .imgInput :checked + label,
.thumbnails-media .imgInput .imgThumbInside {
	background-color: #ddd;
}
.thumbnails-media .selected :checked + label:before,
.thumbnails-media .selected .imgThumbInside:before,
.thumbnails-media .imgInput :checked + label:before,
.thumbnails-media .imgInput .imgThumbInside:before {
	-webkit-transform: scale(1);
	transform: scale(1);
	opacity: 1;
}
.thumbnails-media .selected :checked + label:after,
.thumbnails-media .selected .imgThumbInside:after,
.thumbnails-media .imgInput :checked + label:after,
.thumbnails-media .imgInput .imgThumbInside:after {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	content: '';
	border: 3px solid #46a546;
	border-radius: 5px;
}
.thumbnails-media .imgPreview a {
	padding: 0;
	position: absolute;
	left: 0;
	z-index: 1;
	height: 26px;
	width: 26px;
}
.thumbnails-media .imgPreview a,
.thumbnails-media .imgDetails {
	position: absolute;
	left: 0;
	background-color: #fff;
	border-color: rgba(0,0,0,0.2);
	bottom: 0;
	line-height: 26px;
	border: 1px solid rgba(0,0,0,0.1);
	border-width: 1px 1px 0 0;
	border-radius: 0 3px 0 0;
	z-index: 1;
}
.thumbnails-media .imgPreview a:hover,
.thumbnails-media .imgDetails:hover {
	background-color: #eee;
}
.thumbnails-media .imgDetails {
	padding: 0 5px;
	line-height: 20px;
	color: #555;
}
.thumbnails-media .imgFolder span {
	line-height: 90px;
	font-size: 38px;
	margin: 0;
	width: auto;
}
.thumbnails-media .imgFolder + .imgDetails {
	color: inherit;
}
